==> datacatalog-custom-entries-manager-0.0.1.tar.gz: datacatalog-custom-entries-manager-0.0.1/src/datacatalog_custom_entries_manager/constant.py <==
ENTRIES_DS_CREATED_AT_COLUMN_LABEL = 'created_at'
ENTRIES_DS_DESCRIPTION_COLUMN_LABEL = 'description'
ENTRIES_DS_DISPLAY_NAME_COLUMN_LABEL = 'display_name'
ENTRIES_DS_GROUP_ID_COLUMN_LABEL = 'group_id'
ENTRIES_DS_GROUP_NAME_COLUMN_LABEL = 'group_name'
ENTRIES_DS_LINKED_RESOURCE_COLUMN_LABEL = 'linked_resource'
ENTRIES_DS_UPDATED_AT_COLUMN_LABEL = 'updated_at'
ENTRIES_DS_USER_SPECIFIED_SYSTEM_COLUMN_LABEL = 'user_specified_system'
ENTRIES_DS_USER_SPECIFIED_TYPE_COLUMN_LABEL = 'user_specified_type'

ENTRIES_DS_COLUMNS_ORDER = (ENTRIES_DS_USER_SPECIFIED_SYSTEM_COLUMN_LABEL,
                            ENTRIES_DS_GROUP_ID_COLUMN_LABEL,
                            ENTRIES_DS_GROUP_NAME_COLUMN_LABEL,
                            ENTRIES_DS_DISPLAY_NAME_COLUMN_LABEL,
                            ENTRIES_DS_LINKED_RESOURCE_COLUMN_LABEL,
                            ENTRIES_DS_DESCRIPTION_COLUMN_LABEL,
                            ENTRIES_DS_USER_SPECIFIED_TYPE_COLUMN_LABEL,
                            ENTRIES_DS_CREATED_AT_COLUMN_LABEL,
                            ENTRIES_DS_UPDATED_AT_COLUMN_LABEL)

ENTRIES_DS_FILLABLE_COLUMNS = [
    ENTRIES_DS_USER_SPECIFIED_SYSTEM_COLUMN_LABEL,
    ENTRIES_DS_GROUP_ID_COLUMN_LABEL,
    ENTRIES_DS_GROUP_NAME_COLUMN_LABEL
]

ENTRIES_DS_NON_FILLABLE_COLUMNS = [
    ENTRIES_DS_DISPLAY_NAME_COLUMN_LABEL,
    ENTRIES_DS_LINKED_RESOURCE_COLUMN_LABEL,
    ENTRIES_DS_DESCRIPTION_COLUMN_LABEL,
    ENTRIES_DS_USER_SPECIFIED_TYPE_COLUMN_LABEL,
    ENTRIES_DS_CREATED_AT_COLUMN_LABEL,
    ENTRIES_DS_UPDATED_AT_COLUMN_LABEL
]

ENTRIES_JSON_CREATED_AT_FIELD_NAME = 'createdAt'
ENTRIES_JSON_DESCRIPTION_FIELD_NAME = 'description'
ENTRIES_JSON_DISPLAY_NAME_FIELD_NAME = 'displayName'
ENTRIES_JSON_ENTRIES_FIELD_NAME = 'entries'
ENTRIES_JSON_ENTRY_GROUP_ID_FIELD_NAME = 'id'
ENTRIES_JSON_ENTRY_GROUP_NAME_FIELD_NAME = 'name'
ENTRIES_JSON_ENTRY_GROUPS_FIELD_NAME = 'entryGroups'
ENTRIES_JSON_LINKED_RESOURCE_FIELD_NAME = 'linkedResource'
ENTRIES_JSON_UPDATED_AT_FIELD_NAME = 'updatedAt'
ENTRIES_JSON_USER_SPECIFIED_SYSTEM_FIELD_NAME = 'name'
ENTRIES_JSON_USER_SPECIFIED_SYSTEMS_FIELD_NAME = 'userSpecifiedSystems'
ENTRIES_JSON_USER_SPECIFIED_TYPE_FIELD_NAME = 'type'

==> datacatalog-custom-entries-manager-0.1.1.tar.gz: datacatalog-custom-entries-manager-0.1.1/src/datacatalog_custom_entries_manager/constant.py <==
ENTRIES_DS_CREATED_AT_COLUMN_LABEL = 'created_at'
ENTRIES_DS_DESCRIPTION_COLUMN_LABEL = 'description'
ENTRIES_DS_DISPLAY_NAME_COLUMN_LABEL = 'display_name'
ENTRIES_DS_GROUP_ID_COLUMN_LABEL = 'group_id'
ENTRIES_DS_LINKED_RESOURCE_COLUMN_LABEL = 'linked_resource'
ENTRIES_DS_UPDATED_AT_COLUMN_LABEL = 'updated_at'
ENTRIES_DS_USER_SPECIFIED_SYSTEM_COLUMN_LABEL = 'user_specified_system'
ENTRIES_DS_USER_SPECIFIED_TYPE_COLUMN_LABEL = 'user_specified_type'

ENTRIES_DS_COLUMNS_ORDER = (ENTRIES_DS_USER_SPECIFIED_SYSTEM_COLUMN_LABEL,
                            ENTRIES_DS_GROUP_ID_COLUMN_LABEL, ENTRIES_DS_DISPLAY_NAME_COLUMN_LABEL,
                            ENTRIES_DS_LINKED_RESOURCE_COLUMN_LABEL,
                            ENTRIES_DS_DESCRIPTION_COLUMN_LABEL,
                            ENTRIES_DS_USER_SPECIFIED_TYPE_COLUMN_LABEL,
                            ENTRIES_DS_CREATED_AT_COLUMN_LABEL, ENTRIES_DS_UPDATED_AT_COLUMN_LABEL)

ENTRIES_DS_FILLABLE_COLUMNS = [
    ENTRIES_DS_USER_SPECIFIED_SYSTEM_COLUMN_LABEL,
    ENTRIES_DS_GROUP_ID_COLUMN_LABEL,
]

ENTRIES_DS_NON_FILLABLE_COLUMNS = [
    ENTRIES_DS_DISPLAY_NAME_COLUMN_LABEL,
    ENTRIES_DS_LINKED_RESOURCE_COLUMN_LABEL,
    ENTRIES_DS_DESCRIPTION_COLUMN_LABEL,
    ENTRIES_DS_USER_SPECIFIED_TYPE_COLUMN_LABEL,
    ENTRIES_DS_CREATED_AT_COLUMN_LABEL,
    ENTRIES_DS_UPDATED_AT_COLUMN_LABEL,
]

ENTRIES_JSON_CREATED_AT_FIELD_NAME = 'createdAt'
ENTRIES_JSON_DESCRIPTION_FIELD_NAME = 'description'
ENTRIES_JSON_DISPLAY_NAME_FIELD_NAME = 'displayName'
ENTRIES_JSON_ENTRIES_FIELD_NAME = 'entries'
ENTRIES_JSON_ENTRY_GROUP_ID_FIELD_NAME = 'id'
ENTRIES_JSON_ENTRY_GROUPS_FIELD_NAME = 'entryGroups'
ENTRIES_JSON_LINKED_RESOURCE_FIELD_NAME = 'linkedResource'
ENTRIES_JSON_UPDATED_AT_FIELD_NAME = 'updatedAt'
ENTRIES_JSON_USER_SPECIFIED_SYSTEM_FIELD_NAME = 'name'
ENTRIES_JSON_USER_SPECIFIED_SYSTEMS_FIELD_NAME = 'userSpecifiedSystems'
ENTRIES_JSON_USER_SPECIFIED_TYPE_FIELD_NAME = 'type'
